assert_array_eq

Macro assert_array_eq 

macro_rules! assert_array_eq {
    ($value:expr, $expected:expr) => { ... };
    ($value:expr, $expected:expr, $atol:expr) => { ... };
}
Asserts that two arrays are equal.

It checks that the two arrays have the same shape and that all elements are sufficiently close.

This legacy macro does not compare dtypes and uses its tolerance as both rtol and atol. Workspace tests should use [crate::test_utils::assert_array_eq] for strict comparisons.