pub struct Stream { /* private fields */ }Expand description
A stream of evaluation attached to a particular device.
Typically, this is used via the stream: parameter on a method with a StreamOrDevice:
Implementations
Sourceimpl Stream
impl Stream
Sourcepub fn thread_local_or_default() -> Self
pub fn thread_local_or_default() -> Self
Create a new stream on the default device, or return the thread-local default stream if present.
Sourcepub fn thread_local_or_cpu() -> Self
pub fn thread_local_or_cpu() -> Self
Create a new stream on the default cpu device, or return the thread-local default stream if present.
Sourcepub fn thread_local_or_gpu() -> Self
pub fn thread_local_or_gpu() -> Self
Create a new stream on the default gpu device, or return the thread-local default stream if present.
Sourcepub fn task_local_or_default() -> Self
👎Deprecated since 0.26.0: use Stream::thread_local_or_default
pub fn task_local_or_default() -> Self
use Stream::thread_local_or_default
Returns the thread-local scoped stream or the default stream.
Sourcepub fn task_local_or_cpu() -> Self
👎Deprecated since 0.26.0: use Stream::thread_local_or_cpu
pub fn task_local_or_cpu() -> Self
use Stream::thread_local_or_cpu
Returns the thread-local scoped stream or the CPU stream.
Sourcepub fn task_local_or_gpu() -> Self
👎Deprecated since 0.26.0: use Stream::thread_local_or_gpu
pub fn task_local_or_gpu() -> Self
use Stream::thread_local_or_gpu
Returns the thread-local scoped stream or the GPU stream.
Sourcepub fn try_default_on_device(device: &Device) -> Result<Stream>
pub fn try_default_on_device(device: &Device) -> Result<Stream>
Try to get the default stream on the given device.
Sourcepub fn new_with_device(device: &Device) -> Stream
pub fn new_with_device(device: &Device) -> Stream
Create a new stream on the given device