pub fn with_device<F, T>(device: Device, f: F) -> Twhere
F: FnOnce() -> T,Expand description
Uses the default stream on device for operations constructed during f.
This is equivalent to creating a stream for the device and passing it to with_stream.
Scopes are synchronous, thread-local, nestable, and panic-safe.